This is a simple command line tool with one purpose: It takes a markdown file that has been written with 
each paragraph on a single line (i.e. no newlines between sentences) and returns a the same file with
newlines added between each sentence.  The use case is when one generates text for uploading to a 
blog site, but then wants the text committed to the repository to have one sentence per line for 
easier diffing.  

This app was generated using Claude Code.  See the CLAUDE.md file for the full generation instructions.
